@@ -1,13 +1,17 @@
-from .charsearch import *
-from .aninews import *
-from .anicore import *
+# -*- coding: utf-8 -*-
 
 '''
-An unofficial API to get data about anime characters, anime news and more.
+Animec
+~~~~~~~~~~~~~~~~~~~
+A module to get data about anime characters, news, info, lyrics and more.
 '''
 
+from .sagasu import *
+from .aninews import *
+from .anicore import *
+
 __author__ = "DriftAsimov"
 __title__ = "animec"
 __copyright__ = "Copyright Drift Asimov 2021"
-__version__ = "0.1.0"
-__license__ = "MIT"
\ No newline at end of file
+__version__ = "0.1.2"
+__license__ = "MIT"
